Index — django-ordinary-news v0.0.1 documentation

### Navigation

- index
- django-ordinary-news v0.0.1 documentation »

# Index

D | N | S | T

## D

date (news.models.NewsItem attribute) |

## N

news.models.NewsItem (built-in class) |

## S

short (news.models.NewsItem attribute) slug (news.models.NewsItem attribute) |

## T

text (news.models.NewsItem attribute) title (news.models.NewsItem attribute) |

### Navigation

- index
- django-ordinary-news v0.0.1 documentation »